NAME
VPNDetection::Bogon - the local bogon check behind $client->is_bogon
DESCRIPTION
Implementation detail. Use "is_bogon" in VPNDetection, which is exported on request and is also a method on the client.
VPNDetection::Bogon - the local bogon check behind $client->is_bogon
Implementation detail. Use "is_bogon" in VPNDetection, which is exported on request and is also a method on the client.